==> windmill_api-1.66.0.tar.gz: windmill_api-1.66.0/windmill_api/models/get_hub_flow_by_id_response_200_flow_value_failure_module.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.get_hub_flow_by_id_response_200_flow_value_failure_module_input_transforms import (
    GetHubFlowByIdResponse200FlowValueFailureModuleInputTransforms,
)
from ..models.get_hub_flow_by_id_response_200_flow_value_failure_module_retry import (
    GetHubFlowByIdResponse200FlowValueFailureModuleRetry,
)
from ..models.get_hub_flow_by_id_response_200_flow_value_failure_module_sleep_type_0 import (
    GetHubFlowByIdResponse200FlowValueFailureModuleSleepType0,
)
from ..models.get_hub_flow_by_id_response_200_flow_value_failure_module_sleep_type_1 import (
    GetHubFlowByIdResponse200FlowValueFailureModuleSleepType1,
)
from ..models.get_hub_flow_by_id_response_200_flow_value_failure_module_stop_after_if import (
    GetHubFlowByIdResponse200FlowValueFailureModuleStopAfterIf,
)
from ..models.get_hub_flow_by_id_response_200_flow_value_failure_module_suspend import (
    GetHubFlowByIdResponse200FlowValueFailureModuleSuspend,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="GetHubFlowByIdResponse200FlowValueFailureModule")


@attr.s(auto_attribs=True)
class GetHubFlowByIdResponse200FlowValueFailureModule:
    """
    Attributes:
        id (str):
        value (Any):
        input_transforms (Union[Unset, GetHubFlowByIdResponse200FlowValueFailureModuleInputTransforms]):
        stop_after_if (Union[Unset, GetHubFlowByIdResponse200FlowValueFailureModuleStopAfterIf]):
        sleep (Union[GetHubFlowByIdResponse200FlowValueFailureModuleSleepType0,
            GetHubFlowByIdResponse200FlowValueFailureModuleSleepType1, Unset]):
        summary (Union[Unset, str]):
        suspend (Union[Unset, GetHubFlowByIdResponse200FlowValueFailureModuleSuspend]):
        retry (Union[Unset, GetHubFlowByIdResponse200FlowValueFailureModuleRetry]):
    """

    id: str
    value: Any
    input_transforms: Union[Unset, GetHubFlowByIdResponse200FlowValueFailureModuleInputTransforms] = UNSET
    stop_after_if: Union[Unset, GetHubFlowByIdResponse200FlowValueFailureModuleStopAfterIf] = UNSET
    sleep: Union[
        GetHubFlowByIdResponse200FlowValueFailureModuleSleepType0,
        GetHubFlowByIdResponse200FlowValueFailureModuleSleepType1,
        Unset,
    ] = UNSET
    summary: Union[Unset, str] = UNSET
    suspend: Union[Unset, GetHubFlowByIdResponse200FlowValueFailureModuleSuspend] = UNSET
    retry: Union[Unset, GetHubFlowByIdResponse200FlowValueFailureModuleRetry] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        value = self.value
        input_transforms: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.input_transforms, Unset):
            input_transforms = self.input_transforms.to_dict()

        stop_after_if: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.stop_after_if, Unset):
            stop_after_if = self.stop_after_if.to_dict()

        sleep: Union[Dict[str, Any], Unset]
        if isinstance(self.sleep, Unset):
            sleep = UNSET

        elif isinstance(self.sleep, GetHubFlowByIdResponse200FlowValueFailureModuleSleepType0):
            sleep = UNSET
            if not isinstance(self.sleep, Unset):
                sleep = self.sleep.to_dict()

        else:
            sleep = UNSET
            if not isinstance(self.sleep, Unset):
                sleep = self.sleep.to_dict()

        summary = self.summary
        suspend: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.suspend, Unset):
            suspend = self.suspend.to_dict()

        retry: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.retry, Unset):
            retry = self.retry.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "id": id,
                "value": value,
            }
        )
        if input_transforms is not UNSET:
            field_dict["input_transforms"] = input_transforms
        if stop_after_if is not UNSET:
            field_dict["stop_after_if"] = stop_after_if
        if sleep is not UNSET:
            field_dict["sleep"] = sleep
        if summary is not UNSET:
            field_dict["summary"] = summary
        if suspend is not UNSET:
            field_dict["suspend"] = suspend
        if retry is not UNSET:
            field_dict["retry"] = retry

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("id")

        value = d.pop("value")

        _input_transforms = d.pop("input_transforms", UNSET)
        input_transforms: Union[Unset, GetHubFlowByIdResponse200FlowValueFailureModuleInputTransforms]
        if isinstance(_input_transforms, Unset):
            input_transforms = UNSET
        else:
            input_transforms = GetHubFlowByIdResponse200FlowValueFailureModuleInputTransforms.from_dict(
                _input_transforms
            )

        _stop_after_if = d.pop("stop_after_if", UNSET)
        stop_after_if: Union[Unset, GetHubFlowByIdResponse200FlowValueFailureModuleStopAfterIf]
        if isinstance(_stop_after_if, Unset):
            stop_after_if = UNSET
        else:
            stop_after_if = GetHubFlowByIdResponse200FlowValueFailureModuleStopAfterIf.from_dict(_stop_after_if)

        def _parse_sleep(
            data: object,
        ) -> Union[
            GetHubFlowByIdResponse200FlowValueFailureModuleSleepType0,
            GetHubFlowByIdResponse200FlowValueFailureModuleSleepType1,
            Unset,
        ]:
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _sleep_type_0 = data
                sleep_type_0: Union[Unset, GetHubFlowByIdResponse200FlowValueFailureModuleSleepType0]
                if isinstance(_sleep_type_0, Unset):
                    sleep_type_0 = UNSET
                else:
                    sleep_type_0 = GetHubFlowByIdResponse200FlowValueFailureModuleSleepType0.from_dict(_sleep_type_0)

                return sleep_type_0
            except:  # noqa: E722
                pass
            if not isinstance(data, dict):
                raise TypeError()
            _sleep_type_1 = data
            sleep_type_1: Union[Unset, GetHubFlowByIdResponse200FlowValueFailureModuleSleepType1]
            if isinstance(_sleep_type_1, Unset):
                sleep_type_1 = UNSET
            else:
                sleep_type_1 = GetHubFlowByIdResponse200FlowValueFailureModuleSleepType1.from_dict(_sleep_type_1)

            return sleep_type_1

        sleep = _parse_sleep(d.pop("sleep", UNSET))

        summary = d.pop("summary", UNSET)

        _suspend = d.pop("suspend", UNSET)
        suspend: Union[Unset, GetHubFlowByIdResponse200FlowValueFailureModuleSuspend]
        if isinstance(_suspend, Unset):
            suspend = UNSET
        else:
            suspend = GetHubFlowByIdResponse200FlowValueFailureModuleSuspend.from_dict(_suspend)

        _retry = d.pop("retry", UNSET)
        retry: Union[Unset, GetHubFlowByIdResponse200FlowValueFailureModuleRetry]
        if isinstance(_retry, Unset):
            retry = UNSET
        else:
            retry = GetHubFlowByIdResponse200FlowValueFailureModuleRetry.from_dict(_retry)

        get_hub_flow_by_id_response_200_flow_value_failure_module = cls(
            id=id,
            value=value,
            input_transforms=input_transforms,
            stop_after_if=stop_after_if,
            sleep=sleep,
            summary=summary,
            suspend=suspend,
            retry=retry,
        )

        get_hub_flow_by_id_response_200_flow_value_failure_module.additional_properties = d
        return get_hub_flow_by_id_response_200_flow_value_failure_module

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> windmill_api-1.136.0.tar.gz: windmill_api-1.136.0/windmill_api/models/get_hub_flow_by_id_response_200_flow_value_failure_module.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.get_hub_flow_by_id_response_200_flow_value_failure_module_mock import (
    GetHubFlowByIdResponse200FlowValueFailureModuleMock,
)
from ..models.get_hub_flow_by_id_response_200_flow_value_failure_module_retry import (
    GetHubFlowByIdResponse200FlowValueFailureModuleRetry,
)
from ..models.get_hub_flow_by_id_response_200_flow_value_failure_module_sleep_type_0 import (
    GetHubFlowByIdResponse200FlowValueFailureModuleSleepType0,
)
from ..models.get_hub_flow_by_id_response_200_flow_value_failure_module_sleep_type_1 import (
    GetHubFlowByIdResponse200FlowValueFailureModuleSleepType1,
)
from ..models.get_hub_flow_by_id_response_200_flow_value_failure_module_stop_after_if import (
    GetHubFlowByIdResponse200FlowValueFailureModuleStopAfterIf,
)
from ..models.get_hub_flow_by_id_response_200_flow_value_failure_module_suspend import (
    GetHubFlowByIdResponse200FlowValueFailureModuleSuspend,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="GetHubFlowByIdResponse200FlowValueFailureModule")


@attr.s(auto_attribs=True)
class GetHubFlowByIdResponse200FlowValueFailureModule:
    """
    Attributes:
        id (str):
        value (Any):
        stop_after_if (Union[Unset, GetHubFlowByIdResponse200FlowValueFailureModuleStopAfterIf]):
        sleep (Union[GetHubFlowByIdResponse200FlowValueFailureModuleSleepType0,
            GetHubFlowByIdResponse200FlowValueFailureModuleSleepType1, Unset]):
        cache_ttl (Union[Unset, float]):
        summary (Union[Unset, str]):
        mock (Union[Unset, GetHubFlowByIdResponse200FlowValueFailureModuleMock]):
        suspend (Union[Unset, GetHubFlowByIdResponse200FlowValueFailureModuleSuspend]):
        retry (Union[Unset, GetHubFlowByIdResponse200FlowValueFailureModuleRetry]):
    """

    id: str
    value: Any
    stop_after_if: Union[Unset, GetHubFlowByIdResponse200FlowValueFailureModuleStopAfterIf] = UNSET
    sleep: Union[
        GetHubFlowByIdResponse200FlowValueFailureModuleSleepType0,
        GetHubFlowByIdResponse200FlowValueFailureModuleSleepType1,
        Unset,
    ] = UNSET
    cache_ttl: Union[Unset, float] = UNSET
    summary: Union[Unset, str] = UNSET
    mock: Union[Unset, GetHubFlowByIdResponse200FlowValueFailureModuleMock] = UNSET
    suspend: Union[Unset, GetHubFlowByIdResponse200FlowValueFailureModuleSuspend] = UNSET
    retry: Union[Unset, GetHubFlowByIdResponse200FlowValueFailureModuleRetry] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        value = self.value
        stop_after_if: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.stop_after_if, Unset):
            stop_after_if = self.stop_after_if.to_dict()

        sleep: Union[Dict[str, Any], Unset]
        if isinstance(self.sleep, Unset):
            sleep = UNSET

        elif isinstance(self.sleep, GetHubFlowByIdResponse200FlowValueFailureModuleSleepType0):
            sleep = UNSET
            if not isinstance(self.sleep, Unset):
                sleep = self.sleep.to_dict()

        else:
            sleep = UNSET
            if not isinstance(self.sleep, Unset):
                sleep = self.sleep.to_dict()

        cache_ttl = self.cache_ttl
        summary = self.summary
        mock: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.mock, Unset):
            mock = self.mock.to_dict()

        suspend: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.suspend, Unset):
            suspend = self.suspend.to_dict()

        retry: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.retry, Unset):
            retry = self.retry.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "id": id,
                "value": value,
            }
        )
        if stop_after_if is not UNSET:
            field_dict["stop_after_if"] = stop_after_if
        if sleep is not UNSET:
            field_dict["sleep"] = sleep
        if cache_ttl is not UNSET:
            field_dict["cache_ttl"] = cache_ttl
        if summary is not UNSET:
            field_dict["summary"] = summary
        if mock is not UNSET:
            field_dict["mock"] = mock
        if suspend is not UNSET:
            field_dict["suspend"] = suspend
        if retry is not UNSET:
            field_dict["retry"] = retry

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("id")

        value = d.pop("value")

        _stop_after_if = d.pop("stop_after_if", UNSET)
        stop_after_if: Union[Unset, GetHubFlowByIdResponse200FlowValueFailureModuleStopAfterIf]
        if isinstance(_stop_after_if, Unset):
            stop_after_if = UNSET
        else:
            stop_after_if = GetHubFlowByIdResponse200FlowValueFailureModuleStopAfterIf.from_dict(_stop_after_if)

        def _parse_sleep(
            data: object,
        ) -> Union[
            GetHubFlowByIdResponse200FlowValueFailureModuleSleepType0,
            GetHubFlowByIdResponse200FlowValueFailureModuleSleepType1,
            Unset,
        ]:
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _sleep_type_0 = data
                sleep_type_0: Union[Unset, GetHubFlowByIdResponse200FlowValueFailureModuleSleepType0]
                if isinstance(_sleep_type_0, Unset):
                    sleep_type_0 = UNSET
                else:
                    sleep_type_0 = GetHubFlowByIdResponse200FlowValueFailureModuleSleepType0.from_dict(_sleep_type_0)

                return sleep_type_0
            except:  # noqa: E722
                pass
            if not isinstance(data, dict):
                raise TypeError()
            _sleep_type_1 = data
            sleep_type_1: Union[Unset, GetHubFlowByIdResponse200FlowValueFailureModuleSleepType1]
            if isinstance(_sleep_type_1, Unset):
                sleep_type_1 = UNSET
            else:
                sleep_type_1 = GetHubFlowByIdResponse200FlowValueFailureModuleSleepType1.from_dict(_sleep_type_1)

            return sleep_type_1

        sleep = _parse_sleep(d.pop("sleep", UNSET))

        cache_ttl = d.pop("cache_ttl", UNSET)

        summary = d.pop("summary", UNSET)

        _mock = d.pop("mock", UNSET)
        mock: Union[Unset, GetHubFlowByIdResponse200FlowValueFailureModuleMock]
        if isinstance(_mock, Unset):
            mock = UNSET
        else:
            mock = GetHubFlowByIdResponse200FlowValueFailureModuleMock.from_dict(_mock)

        _suspend = d.pop("suspend", UNSET)
        suspend: Union[Unset, GetHubFlowByIdResponse200FlowValueFailureModuleSuspend]
        if isinstance(_suspend, Unset):
            suspend = UNSET
        else:
            suspend = GetHubFlowByIdResponse200FlowValueFailureModuleSuspend.from_dict(_suspend)

        _retry = d.pop("retry", UNSET)
        retry: Union[Unset, GetHubFlowByIdResponse200FlowValueFailureModuleRetry]
        if isinstance(_retry, Unset):
            retry = UNSET
        else:
            retry = GetHubFlowByIdResponse200FlowValueFailureModuleRetry.from_dict(_retry)

        get_hub_flow_by_id_response_200_flow_value_failure_module = cls(
            id=id,
            value=value,
            stop_after_if=stop_after_if,
            sleep=sleep,
            cache_ttl=cache_ttl,
            summary=summary,
            mock=mock,
            suspend=suspend,
            retry=retry,
        )

        get_hub_flow_by_id_response_200_flow_value_failure_module.additional_properties = d
        return get_hub_flow_by_id_response_200_flow_value_failure_module

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
